var indexSectionsWithContent =
{
  0: "_abcdefghijklmnopqrstuvwxyz~",
  1: "abcdefhilmoprstuvy",
  2: "l",
  3: "abcdefghilmoprstuvy",
  4: "_abcdefghijklmnopqrstuvwxyz~",
  5: "abcdefghiklmnopqrstuvwxy",
  6: "bcdfhimoprst",
  7: "abcdefhilmnoprstwy",
  8: "abcdefghiklmnoprstuvw",
  9: "o",
  10: "ailr",
  11: "aclmrst"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "related",
  10: "defines",
  11: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Friends",
  10: "Macros",
  11: "Pages"
};

